@@ -274,7 +274,7 @@ class PlayerCommands(MixinMeta, metaclass=CompositeMetaClass):
                 description=_("This track is not allowed in this server."),
             )
         elif guild_data["maxlength"] > 0:
-            if self.is_track_too_long(single_track, guild_data["maxlength"]):
+            if self.is_track_length_allowed(single_track, guild_data["maxlength"]):
                 single_track.requester = ctx.author
                 player.queue.insert(0, single_track)
                 player.maybe_shuffle()
@@ -576,6 +576,16 @@ class PlayerCommands(MixinMeta, metaclass=CompositeMetaClass):
                 notify_channel = self.bot.get_channel(notify_channel)
                 await self.send_embed_msg(notify_channel, title=_("Couldn't get a valid track."))
             return
+        except TrackEnqueueError:
+            self.update_player_lock(ctx, False)
+            return await self.send_embed_msg(
+                ctx,
+                title=_("Unable to Get Track"),
+                description=_(
+                    "I'm unable get a track from Lavalink at the moment, try again in a few "
+                    "minutes."
+                ),
+            )
 
         if not guild_data["auto_play"]:
             await ctx.invoke(self.command_audioset_autoplay_toggle)
@@ -593,7 +603,7 @@ class PlayerCommands(MixinMeta, metaclass=CompositeMetaClass):
         """Pick a track with a search.
 
         Use `[p]search list <search term>` to queue all tracks found on YouTube.
-        Use `[p]search sc<search term>` will search SoundCloud instead of YouTube.
+        Use `[p]search sc <search term>` will search SoundCloud instead of YouTube.
         """
 
         async def _search_menu(
@@ -763,7 +773,7 @@ class PlayerCommands(MixinMeta, metaclass=CompositeMetaClass):
                             log.debug(f"Query is not allowed in {ctx.guild} ({ctx.guild.id})")
                         continue
                     elif guild_data["maxlength"] > 0:
-                        if self.is_track_too_long(track, guild_data["maxlength"]):
+                        if self.is_track_length_allowed(track, guild_data["maxlength"]):
                             track_len += 1
                             player.add(ctx.author, track)
                             self.bot.dispatch(
