@@ -3,6 +3,7 @@ from typing import cast, Optional
 
 import discord
 from redbot.core import commands, checks, i18n, modlog
+from redbot.core.utils import AsyncIter
 from redbot.core.utils.chat_formatting import format_perms_list
 from redbot.core.utils.mod import get_audit_reason, is_allowed_by_hierarchy
 from .abc import MixinMeta
@@ -207,6 +208,17 @@ class MuteMixin(MixinMeta):
             await ctx.send(
                 _("Muted {user} in channel {channel.name}").format(user=user, channel=channel)
             )
+            try:
+                if channel.permissions_for(ctx.me).move_members:
+                    await user.move_to(channel)
+                else:
+                    raise RuntimeError
+            except (discord.Forbidden, RuntimeError):
+                await ctx.send(
+                    _(
+                        "Because I don't have the Move Members permission, this will take into effect when the user rejoins."
+                    )
+                )
         else:
             await ctx.send(issue)
 
@@ -255,11 +267,10 @@ class MuteMixin(MixinMeta):
         audit_reason = get_audit_reason(author, reason)
 
         mute_success = []
-        for channel in guild.channels:
-            success, issue = await self.mute_user(guild, channel, author, user, audit_reason)
-            mute_success.append((success, issue))
-            await asyncio.sleep(0.1)
-        try:
+        async with ctx.typing():
+            for channel in guild.channels:
+                success, issue = await self.mute_user(guild, channel, author, user, audit_reason)
+                mute_success.append((success, issue))
             await modlog.create_case(
                 self.bot,
                 guild,
@@ -271,9 +282,7 @@ class MuteMixin(MixinMeta):
                 until=None,
                 channel=None,
             )
-        except RuntimeError as e:
-            await ctx.send(e)
-        await ctx.send(_("User has been muted in this server."))
+            await ctx.send(_("User has been muted in this server."))
 
     @commands.group()
     @commands.guild_only()
@@ -322,6 +331,17 @@ class MuteMixin(MixinMeta):
             await ctx.send(
                 _("Unmuted {user} in channel {channel.name}").format(user=user, channel=channel)
             )
+            try:
+                if channel.permissions_for(ctx.me).move_members:
+                    await user.move_to(channel)
+                else:
+                    raise RuntimeError
+            except (discord.Forbidden, RuntimeError):
+                await ctx.send(
+                    _(
+                        "Because I don't have the Move Members permission, this will take into effect when the user rejoins."
+                    )
+                )
         else:
             await ctx.send(_("Unmute failed. Reason: {}").format(message))
 
@@ -372,11 +392,12 @@ class MuteMixin(MixinMeta):
         audit_reason = get_audit_reason(author, reason)
 
         unmute_success = []
-        for channel in guild.channels:
-            success, message = await self.unmute_user(guild, channel, author, user, audit_reason)
-            unmute_success.append((success, message))
-            await asyncio.sleep(0.1)
-        try:
+        async with ctx.typing():
+            for channel in guild.channels:
+                success, message = await self.unmute_user(
+                    guild, channel, author, user, audit_reason
+                )
+                unmute_success.append((success, message))
             await modlog.create_case(
                 self.bot,
                 guild,
@@ -387,9 +408,7 @@ class MuteMixin(MixinMeta):
                 reason,
                 until=None,
             )
-        except RuntimeError as e:
-            await ctx.send(e)
-        await ctx.send(_("User has been unmuted in this server."))
+            await ctx.send(_("User has been unmuted in this server."))
 
     async def mute_user(
         self,
